========================
Submitting pull requests
========================

* To avoid disappointment, new features should be discussed on the mailing list
  (django-oscar@googlegroups.com) before serious work starts. 

* Write tests! Pull requests will be rejected if sufficient tests aren't
  provided. 

* Write docs! Please update the documentation when altering behaviour or introducing new features.

* Write good commit messages: see `Tim Pope's excellent note`_.

* Make pull requests against Oscar's master branch unless instructed otherwise.

* Always submit pull requests from a custom branch.  Don't submit from your
  master branch.  

.. _`Tim Pope's excellent note`: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html
